#include "circular_buffer.h"

/**
 * @brief Attempt to push a given value into a given buffer.
 *
 * @params a buffer.
 * @params the value that will be pushed.
 * @returns true, if the value was successfully pushed.
 */
bool circular_buffer_push(CircularBuffer* buffer, uint8_t value)
{
	if (buffer->size >= CIRCULAR_BUFFER_SIZE)
	{
		return false;
	}

	buffer->data[(buffer->start + buffer->size) % CIRCULAR_BUFFER_SIZE] = value;
	buffer->size++;

	return true;
}

/**
 * @brief Attempt to pop a value from a given buffer.
 *        If function fails value will be set to zero.
 *
 * @params buffer.
 * @params pointer to a value.
 * @returns true, if the value was successfully popped.
 */
bool circular_buffer_pop(CircularBuffer* buffer, uint8_t* value)
{
	if (buffer->size == 0)
	{
		value = 0;

		return false;
	}

	*value = buffer->data[buffer->start];
	buffer->size--;
	buffer->start = (buffer->start + 1) % CIRCULAR_BUFFER_SIZE;

	return true;
}
