#include <stddef.h>

#include "matrix_buffer.h"

/**
 * @brief Attempt to push a given value into a row.
 *
 * @param row.
 * @param value.
 * @returns true, if value was pushed, false otherwise.
 */
bool matrix_row_push(MatrixRow* row, uint8_t value)
{
	if (row->size >= MATRIX_BUFFER_COLUMNS)
	{
		return false;
	}

	row->data[row->size] = value;
	row->size++;

	return true;
}

/**
 * @brief Find a following row after a given row.
 *
 * @param buffer.
 * @param row.
 * @returns a following row.
 */
MatrixRow* matrix_buffer_next_row(MatrixBuffer* buffer, MatrixRow* row)
{
	ptrdiff_t current_row_index = row - buffer->rows;
	ptrdiff_t next_row_index = (current_row_index + 1) % MATRIX_BUFFER_ROWS;

	return buffer->rows + next_row_index;
}
